module.exports = defineTest({
	description: 'inlines dynamic imports that are already statically imported by their importers'
});
